@@ -20,9 +20,25 @@ _LOGGER = logging.getLogger(__name__)
 
 
 class C4Account:
-    def __init__(self, username, password):
+    def __init__(
+        self,
+        username,
+        password,
+        session: aiohttp.ClientSession = None,
+    ):
+        """Creates a Control4 account object.
+
+        Parameters:
+            `username` - Control4 account username/email.
+
+            `password` - Control4 account password.
+
+            `session` - (Optional) Allows the use of an `aiohttp.ClientSession` object for all network requests. This session will not be closed by the library.
+            If not provided, the library will open and close its own `ClientSession`s as needed.
+        """
         self.username = username
         self.password = password
+        self.session = session
 
     async def __sendAccountAuthRequest(self):
         """Used internally to retrieve an account bearer token. Returns the entire
@@ -45,9 +61,17 @@ class C4Account:
                 },
             }
         }
-        async with aiohttp.ClientSession() as session:
+        if self.session is None:
+            async with aiohttp.ClientSession() as session:
+                with async_timeout.timeout(10):
+                    async with session.post(
+                        AUTHENTICATION_ENDPOINT, json=dataDictionary
+                    ) as resp:
+                        await checkResponseForError(await resp.text())
+                        return await resp.text()
+        else:
             with async_timeout.timeout(10):
-                async with session.post(
+                async with self.session.post(
                     AUTHENTICATION_ENDPOINT, json=dataDictionary
                 ) as resp:
                     await checkResponseForError(await resp.text())
@@ -67,9 +91,15 @@ class C4Account:
             msg = "The account bearer token is missing - was your username/password correct? "
             _LOGGER.error(msg)
             raise
-        async with aiohttp.ClientSession() as session:
+        if self.session is None:
+            async with aiohttp.ClientSession() as session:
+                with async_timeout.timeout(10):
+                    async with session.get(uri, headers=headers) as resp:
+                        await checkResponseForError(await resp.text())
+                        return await resp.text()
+        else:
             with async_timeout.timeout(10):
-                async with session.get(uri, headers=headers) as resp:
+                async with self.session.get(uri, headers=headers) as resp:
                     await checkResponseForError(await resp.text())
                     return await resp.text()
 
@@ -92,9 +122,19 @@ class C4Account:
                 "services": "director",
             }
         }
-        async with aiohttp.ClientSession() as session:
+        if self.session is None:
+            async with aiohttp.ClientSession() as session:
+                with async_timeout.timeout(10):
+                    async with session.post(
+                        CONTROLLER_AUTHORIZATION_ENDPOINT,
+                        headers=headers,
+                        json=dataDictionary,
+                    ) as resp:
+                        await checkResponseForError(await resp.text())
+                        return await resp.text()
+        else:
             with async_timeout.timeout(10):
-                async with session.post(
+                async with self.session.post(
                     CONTROLLER_AUTHORIZATION_ENDPOINT,
                     headers=headers,
                     json=dataDictionary,
@@ -103,8 +143,7 @@ class C4Account:
                     return await resp.text()
 
     async def getAccountBearerToken(self):
-        """Gets an account bearer token for making Control4 online API requests.
-        """
+        """Gets an account bearer token for making Control4 online API requests."""
         data = await self.__sendAccountAuthRequest()
         jsonDictionary = json.loads(data)
         try:
