@@ -1,9 +1,5 @@
 """Controls Control4 Light devices.
 """
-import aiohttp
-import asyncio
-import async_timeout
-from .director import C4Director
 
 
 class C4Light:
@@ -11,7 +7,7 @@ class C4Light:
         """Creates a Control4 Light object.
 
         Parameters:
-            `C4Director` - A `C4Director` object that corresponds to the Control4 Director that the light is connected to. See `director.py` for details.
+            `C4Director` - A `pyControl4.director.C4Director` object that corresponds to the Control4 Director that the light is connected to.
 
             `item_id` - The Control4 item ID of the light.
         """
@@ -26,13 +22,12 @@ class C4Light:
         return int(value)
 
     async def getState(self):
-        """Returns the power state of a dimmer or switch as a boolean (True=on, False=off).
-        """
+        """Returns the power state of a dimmer or switch as a boolean (True=on, False=off)."""
         value = await self.director.getItemVariableValue(self.item_id, "LIGHT_STATE")
         return bool(value)
 
     async def setLevel(self, level):
-        """Sets the light level of a dimmer or turns on/off a switch. 
+        """Sets the light level of a dimmer or turns on/off a switch.
         Any `level > 0` will turn on a switch, and `level = 0` will turn off a switch.
 
         Parameters:
@@ -45,7 +40,7 @@ class C4Light:
         )
 
     async def rampToLevel(self, level, time):
-        """Ramps the light level of a dimmer over time. 
+        """Ramps the light level of a dimmer over time.
         Any `level > 0` will turn on a switch, and `level = 0` will turn off a switch.
 
         Parameters:
